Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(10)

Unified Diff: ppapi/c/ppb_image_data.h

Issue 6085009: Add an instance parameter to var objects, audio, and the 2D API. This replace... (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: Created 9 years, 12 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ppapi/c/ppb_graphics_2d.h ('k') | ppapi/cpp/dev/audio_config_dev.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ppapi/c/ppb_image_data.h
===================================================================
--- ppapi/c/ppb_image_data.h (revision 70488)
+++ ppapi/c/ppb_image_data.h (working copy)
@@ -6,6 +6,7 @@
#define PPAPI_C_PPB_IMAGE_DATA_H_
#include "ppapi/c/pp_bool.h"
+#include "ppapi/c/pp_instance.h"
#include "ppapi/c/pp_macros.h"
#include "ppapi/c/pp_module.h"
#include "ppapi/c/pp_resource.h"
@@ -31,7 +32,7 @@
};
PP_COMPILE_ASSERT_STRUCT_SIZE_IN_BYTES(PP_ImageDataDesc, 16);
-#define PPB_IMAGEDATA_INTERFACE "PPB_ImageData;0.2"
+#define PPB_IMAGEDATA_INTERFACE "PPB_ImageData;0.3"
/**
* @file
@@ -58,7 +59,7 @@
/**
* Allocates an image data resource with the given format and size. The
* return value will have a nonzero ID on success, or zero on failure.
* Failure means the module handle, image size, or format was invalid.
*
* Set the init_to_zero flag if you want the bitmap initialized to
* transparent during the creation process. If this flag is not set, the
@@ -69,7 +70,7 @@
* memory, but may contain data from a previous image produced by the same
* plugin if the bitmap was cached and re-used.
*/
- PP_Resource (*Create)(PP_Module module,
+ PP_Resource (*Create)(PP_Instance instance,
PP_ImageDataFormat format,
const struct PP_Size* size,
PP_Bool init_to_zero);
@@ -58,7 +59,7 @@
* Allocates an image data resource with the given format and size. The
* return value will have a nonzero ID on success, or zero on failure.
- * Failure means the module handle, image size, or format was invalid.
+ * Failure means the instance, image size, or format was invalid.
*
* Set the init_to_zero flag if you want the bitmap initialized to
« no previous file with comments | « ppapi/c/ppb_graphics_2d.h ('k') | ppapi/cpp/dev/audio_config_dev.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698